## d32owc.mak (DOS32 single-threaded static library, OpenWatcom C/C++) ##

##----------------------------------------------------------------------
## Build DOS32 version of GLPK solver executable
## Needs OpenWatcom C compiler from http://www.openwatcom.org
##
## Written by Vasily Zatsepin <zwb@online.ru>.
##
## To compile GLPK with OpenWatcom C for DOS32 enter the subdirectory
## where the file you are reading is placed and type the command:
##
##    wmake.exe -f d32owc.mak
##
## The following two files will be created in the same subdirectory:
##
##    glpk.lib,   GLPK static library, and
##
##    glpsol.exe, stand-alone LP/MIP solver.
##
## To check if GLPK has been successfully compiled type the command:
##
##    wmake.exe -f d32owc.mak check
##
## Header files needed to use the GLPK static library are contained in
## the subdirectory 'include'.
##----------------------------------------------------------------------

CFLAGS = -w4 -e25 -bt=dos -otexan -dNDEBUG -d__dos

C_DIR = src\
EX_DIR = examples\

.c: $(C_DIR);$(EX_DIR)
.obj: $(EX_DIR)
.c.obj:
        wcc386.exe $(CFLAGS) -iinclude $[* -fo$*.obj

all: glpk.lib glpsol.exe tspsol.exe

check: glpsol.exe
        glpsol.exe examples\plan.mps

glpk.lib: src\glpavl.obj &
        src\glpdmp.obj &
        src\glphbm.obj &
        src\glpiet.obj &
        src\glpinv.obj &
        src\glpios1.obj &
        src\glpios2.obj &
        src\glpios3.obj &
        src\glpipm.obj &
        src\glpipp1.obj &
        src\glpipp2.obj &
        src\glplib1a.obj &
        src\glplib1b.obj &
        src\glplib2.obj &
        src\glplib3.obj &
        src\glplib4.obj &
        src\glplpp1.obj &
        src\glplpp2.obj &
        src\glplpx1.obj &
        src\glplpx2.obj &
        src\glplpx3.obj &
        src\glplpx4.obj &
        src\glplpx5.obj &
        src\glplpx6a.obj &
        src\glplpx6b.obj &
        src\glplpx6c.obj &
        src\glplpx6d.obj &
        src\glplpx7.obj &
        src\glplpx7a.obj &
        src\glplpx8a.obj &
        src\glplpx8b.obj &
        src\glplpx8c.obj &
        src\glplpx8d.obj &
        src\glplpx8e.obj &
        src\glpluf.obj &
        src\glpmat.obj &
        src\glpmip1.obj &
        src\glpmip2.obj &
        src\glpmpl1.obj &
        src\glpmpl2.obj &
        src\glpmpl3.obj &
        src\glpmpl4.obj &
        src\glpqmd.obj &
        src\glprng.obj &
        src\glpspx1.obj &
        src\glpspx2.obj &
        src\glpstr.obj &
        src\glptsp.obj
        wlib.exe -n $@ +$<

glpsol.exe: examples\glpsol.obj glpk.lib
# ! To choose extender just uncomment one !
#        wcl386.exe -fe=glpsol.exe -l=CauseWay examples\glpsol.obj glpk.lib # With CauseWay public domain extender
        wcl386.exe -fe=glpsol.exe -l=DOS4G examples\glpsol.obj glpk.lib # With Tenberry Software DOS extender
#        wcl386.exe -fe=glpsol.exe -l=DOS4GNZ examples\glpsol.obj glpk.lib # With Tenberry Software DOS extender

tspsol.exe: examples\tspsol.obj glpk.lib
# ! To choose extender just uncomment one !
#        wcl386.exe -fe=tspsol.exe -l=CauseWay examples\tspsol.obj glpk.lib # With CauseWay public domain extender
        wcl386.exe -fe=tspsol.exe -l=DOS4G examples\tspsol.obj glpk.lib # With Tenberry Software DOS extender
#        wcl386.exe -fe=tspsol.exe -l=DOS4GNZ examples\tspsol.obj glpk.lib # With Tenberry Software DOS extender

        del *.err
        del src\*.obj
        del examples\*.obj

## eof ##
